Index: third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h |
diff --git a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h b/third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h |
similarity index 86% |
rename from third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h |
rename to third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h |
index 078a95b2fceb20e743154bdd4f60fde194c355b2..419ae2d422ded9e13f47d6fb9a1154e4b79df159 100644 |
--- a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h |
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h |
@@ -28,8 +28,8 @@ |
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#ifndef WorkerGlobalScopeProxy_h |
-#define WorkerGlobalScopeProxy_h |
+#ifndef InProcessWorkerGlobalScopeProxy_h |
+#define InProcessWorkerGlobalScopeProxy_h |
#include "core/CoreExport.h" |
#include "core/dom/MessagePort.h" |
@@ -41,11 +41,11 @@ namespace blink { |
class KURL; |
-// A proxy to talk to the worker global scope. |
-class CORE_EXPORT WorkerGlobalScopeProxy { |
- USING_FAST_MALLOC(WorkerGlobalScopeProxy); |
+// A proxy to talk to the in-process worker global scope. |
+class CORE_EXPORT InProcessWorkerGlobalScopeProxy { |
+ USING_FAST_MALLOC(InProcessWorkerGlobalScopeProxy); |
public: |
- virtual ~WorkerGlobalScopeProxy() { } |
+ virtual ~InProcessWorkerGlobalScopeProxy() { } |
virtual void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) = 0; |
@@ -60,4 +60,4 @@ public: |
} // namespace blink |
-#endif // WorkerGlobalScopeProxy_h |
+#endif // InProcessWorkerGlobalScopeProxy_h |